==> analytics.js-integration-mediamath-2.0.0.tgz: package/lib/index.js <==
'use strict';

/**
 * Module dependencies.
 */

var integration = require('@segment/analytics.js-integration');
var qs = require('component-querystring');
var extend = require('@ndhoule/extend');
var foldl = require('@ndhoule/foldl');
var each = require('component-each');

/**
 * Expose `MediaMath`
 */

var MediaMath = module.exports = integration('MediaMath')
  .option('allPagesMtId', '')
  .option('allPagesMtAdId', '')
  .option('events', [])
  .mapping('events')
  .tag('page', '<script src="//pixel.mathtag.com/event/js?mt_id={{ allPagesMtId }}&mt_adid={{ allPagesMtAdId }}&v1=&v2=&v3=&s1=&s2=&s3=">')
  .tag('conversion', '<script src="//pixel.mathtag.com/event/js?{{ query }}">');

/**
 * Initialize.
 *
 * @api public
 */

MediaMath.prototype.initialize = function() {
  var allPagesMtId = this.options.allPagesMtId;
  var allPagesMtAdId = this.options.allPagesMtAdId;
  if (allPagesMtId && allPagesMtAdId) this.load('page');
  this.ready();
};

/**
 * Loaded.
 *
 * @api public
 * @return {boolean}
 */

MediaMath.prototype.loaded = function() {
  // MediaMath loads pixels on demand, so it doesn't need to be pre-loaded
  return true;
};

/**
 * Track.
 *
 * @api public
 * @param {Track} track
 */

MediaMath.prototype.track = function(track) {
  var events = this.events(track.event());
  var self = this;
  each(events, function(event) {
    // sParams and vParams are arbitrarily separated,
    // any of either can be assigned any dynamic value.
    var queryParamPropertyMap = extend({}, event.vParameters || {}, event.sParameters || {});

    // front-load query accumulator with empty string defaults
    // so that resulting qs will be formatted correctly
    // without omission of mandatory keys (&v1=&v2=&v3=&s1=&s2=&s3=)
    var query = foldl(function(query, mappedKey, property) {
      var value;

      if (property === 'revenue') {
        value = (track.revenue() || 0).toFixed(2);
      } else {
        value = track.proxy('properties.' + property);
      }

      if (value !== undefined && value !== null) {
        query[mappedKey] = value;
      }

      return query;
    }, {
      mt_id: event.mtId || '',
      mt_adid: event.mtAdId || '',
      v1: '',
      v2: '',
      v3: '',
      s1: '',
      s2: '',
      s3: ''
    }, queryParamPropertyMap);

    self.load('conversion', { query: qs.stringify(query) });
  });
};

==> analytics.js-integration-mediamath-2.0.1.tgz: package/lib/index.js <==
'use strict';

/**
 * Module dependencies.
 */

var integration = require('@segment/analytics.js-integration');
var qs = require('component-querystring');
var foldl = require('@ndhoule/foldl');
var each = require('component-each');

/**
 * Expose `MediaMath`
 */

var MediaMath = module.exports = integration('MediaMath')
  .option('allPagesMtId', '')
  .option('allPagesMtAdId', '')
  .option('events', [])
  .mapping('events')
  .tag('page', '<script src="//pixel.mathtag.com/event/js?mt_id={{ allPagesMtId }}&mt_adid={{ allPagesMtAdId }}&v1=&v2=&v3=&s1=&s2=&s3=">')
  .tag('conversion', '<script src="//pixel.mathtag.com/event/js?{{ query }}">');

/**
 * Initialize.
 *
 * @api public
 */

MediaMath.prototype.initialize = function() {
  var allPagesMtId = this.options.allPagesMtId;
  var allPagesMtAdId = this.options.allPagesMtAdId;
  if (allPagesMtId && allPagesMtAdId) this.load('page');
  this.ready();
};

/**
 * Loaded.
 *
 * @api public
 * @return {boolean}
 */

MediaMath.prototype.loaded = function() {
  // MediaMath loads pixels on demand, so it doesn't need to be pre-loaded
  return true;
};

/**
 * Track.
 *
 * @api public
 * @param {Track} track
 */

MediaMath.prototype.track = function(track) {
  var events = this.events(track.event());
  var self = this;
  each(events, function(event) {
    // sParams and vParams are arbitrarily separated,
    // any of either can be assigned any dynamic value.
    var queryParamPropertyMap = [].concat(event.vParameters || [], event.sParameters || []);

    // front-load query accumulator with empty string defaults
    // so that resulting qs will be formatted correctly
    // without omission of mandatory keys (&v1=&v2=&v3=&s1=&s2=&s3=)
    var query = foldl(function(query, kv) {
      var property = kv && kv.key;
      var mappedKey = kv && kv.value;
      if (!(property && mappedKey)) return query;

      var value;
      if (property === 'revenue') {
        value = (track.revenue() || 0).toFixed(2);
      } else {
        value = track.proxy('properties.' + property);
      }

      if (value !== undefined && value !== null) {
        query[mappedKey] = value;
      }

      return query;
    }, {
      mt_id: event.mtId || '',
      mt_adid: event.mtAdId || '',
      v1: '',
      v2: '',
      v3: '',
      s1: '',
      s2: '',
      s3: ''
    }, queryParamPropertyMap);

    self.load('conversion', { query: qs.stringify(query) });
  });
};
